/****************************************************************************
** Meta object code from reading C++ file 'poweroperatormodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-power/operation/poweroperatormodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'poweroperatormodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18PowerOperatorModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerOperatorModel::qt_create_metaobjectdata<qt_meta_tag_ZN18PowerOperatorModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerOperatorModel",
        "QML.Element",
        "keyOfIndex",
        "",
        "rowIndex",
        "indexOfKey",
        "key",
        "PowerOperatorRole",
        "KeyRole",
        "TextRole",
        "VisibleRole",
        "EnableRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'keyOfIndex'
        QtMocHelpers::MethodData<quint8(int) const>(2, 3, QMC::AccessPublic, QMetaType::UChar, {{
            { QMetaType::Int, 4 },
        }}),
        // Method 'indexOfKey'
        QtMocHelpers::MethodData<int(quint8) const>(5, 3, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::UChar, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PowerOperatorRole'
        QtMocHelpers::EnumData<enum PowerOperatorRole>(7, 7, QMC::EnumFlags{}).add({
            {    8, PowerOperatorRole::KeyRole },
            {    9, PowerOperatorRole::TextRole },
            {   10, PowerOperatorRole::VisibleRole },
            {   11, PowerOperatorRole::EnableRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
    });
    return QtMocHelpers::metaObjectData<PowerOperatorModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerOperatorModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PowerOperatorModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PowerOperatorModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PowerOperatorModelE_t>.metaTypes,
    nullptr
} };

void PowerOperatorModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerOperatorModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { quint8 _r = _t->keyOfIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<quint8*>(_a[0]) = std::move(_r); }  break;
        case 1: { int _r = _t->indexOfKey((*reinterpret_cast<std::add_pointer_t<quint8>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *PowerOperatorModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerOperatorModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PowerOperatorModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int PowerOperatorModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
