/****************************************************************************
** Meta object code from reading C++ file 'notificationsetting.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-control-center/src/plugin-notification/operation/notificationsetting.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationsetting.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DCC_NAMESPACE19NotificationSettingE_t {};
} // unnamed namespace

template <> constexpr inline auto DCC_NAMESPACE::NotificationSetting::qt_create_metaobjectdata<qt_meta_tag_ZN13DCC_NAMESPACE19NotificationSettingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DCC_NAMESPACE::NotificationSetting",
        "appAdded",
        "",
        "appId",
        "appRemoved",
        "id",
        "appValueChanged",
        "configItem",
        "QVariant",
        "value",
        "systemValueChanged",
        "key",
        "onAppsChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'appAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'appRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'appValueChanged'
        QtMocHelpers::SignalData<void(const QString &, uint, const QVariant &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'systemValueChanged'
        QtMocHelpers::SignalData<void(uint, const QVariant &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'systemValueChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'onAppsChanged'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotificationSetting, qt_meta_tag_ZN13DCC_NAMESPACE19NotificationSettingE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DCC_NAMESPACE::NotificationSetting::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE19NotificationSettingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE19NotificationSettingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DCC_NAMESPACE19NotificationSettingE_t>.metaTypes,
    nullptr
} };

void DCC_NAMESPACE::NotificationSetting::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationSetting *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->appAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->appRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->appValueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 3: _t->systemValueChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 4: _t->systemValueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->onAppsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotificationSetting::*)(const QString & )>(_a, &NotificationSetting::appAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSetting::*)(const QString & )>(_a, &NotificationSetting::appRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSetting::*)(const QString & , uint , const QVariant & )>(_a, &NotificationSetting::appValueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSetting::*)(uint , const QVariant & )>(_a, &NotificationSetting::systemValueChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationSetting::*)(const QString & )>(_a, &NotificationSetting::systemValueChanged, 4))
            return;
    }
}

const QMetaObject *DCC_NAMESPACE::NotificationSetting::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DCC_NAMESPACE::NotificationSetting::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DCC_NAMESPACE19NotificationSettingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DCC_NAMESPACE::NotificationSetting::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DCC_NAMESPACE::NotificationSetting::appAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DCC_NAMESPACE::NotificationSetting::appRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DCC_NAMESPACE::NotificationSetting::appValueChanged(const QString & _t1, uint _t2, const QVariant & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void DCC_NAMESPACE::NotificationSetting::systemValueChanged(uint _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void DCC_NAMESPACE::NotificationSetting::systemValueChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
